API Reference
=============

This is the API reference for the rvspecfit package.

.. automodule:: rvspecfit.vel_fit
   :members:

.. automodule:: rvspecfit.spec_fit
   :members:

.. automodule:: rvspecfit.fitter_ccf
   :members:

.. automodule:: rvspecfit.make_ccf
   :members:

.. automodule:: rvspecfit.make_interpol
   :members:

.. automodule:: rvspecfit.make_nd
   :members:

.. automodule:: rvspecfit.read_grid
   :members:

.. automodule:: rvspecfit.regularize_grid
   :members:

.. automodule:: rvspecfit.serializer
   :members:

.. automodule:: rvspecfit.spec_inter
   :members:

.. automodule:: rvspecfit.spliner
   :members:

.. automodule:: rvspecfit.utils
   :members:
